@@ -66,8 +66,10 @@ import org.apache.bookkeeper.stats.StatsLogger;
 import org.apache.bookkeeper.util.DiskChecker;
 import org.apache.bookkeeper.util.HardLink;
 import org.apache.bookkeeper.util.IOUtils;
+import org.apache.bookkeeper.util.LedgerDirUtil;
 import org.apache.bookkeeper.util.collections.ConcurrentLongLongHashMap;
 import org.apache.bookkeeper.util.collections.ConcurrentLongLongHashMap.BiConsumerLong;
+import org.apache.commons.lang3.tuple.Pair;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -342,7 +344,17 @@ public class DefaultEntryLogger implements EntryLogger {
                 throw new FileNotFoundException(
                         "Entry log directory '" + dir + "' does not exist");
             }
-            long lastLogId = getLastLogId(dir);
+            long lastLogId;
+            long lastLogFileFromFile = getLastLogIdFromFile(dir);
+            long lastLogIdInDir = getLastLogIdInDir(dir);
+            if (lastLogFileFromFile < lastLogIdInDir) {
+                LOG.info("The lastLogFileFromFile is {}, the lastLogIdInDir is {}, "
+                        + "use lastLogIdInDir as the lastLogId.", lastLogFileFromFile, lastLogIdInDir);
+                lastLogId = lastLogIdInDir;
+            } else {
+                lastLogId = lastLogFileFromFile;
+            }
+
             if (lastLogId > logId) {
                 logId = lastLogId;
             }
@@ -532,7 +544,7 @@ public class DefaultEntryLogger implements EntryLogger {
         return true;
     }
 
-    private long getLastLogId(File dir) {
+    private long getLastLogIdFromFile(File dir) {
         long id = readLastLogId(dir);
         // read success
         if (id > 0) {
@@ -556,6 +568,17 @@ public class DefaultEntryLogger implements EntryLogger {
         return logs.get(logs.size() - 1);
     }
 
+    private long getLastLogIdInDir(File dir) {
+        List<Integer> currentIds = new ArrayList<Integer>();
+        currentIds.addAll(LedgerDirUtil.logIdsInDirectory(dir));
+        currentIds.addAll(LedgerDirUtil.compactedLogIdsInDirectory(dir));
+        if (currentIds.isEmpty()) {
+            return -1;
+        }
+        Pair<Integer, Integer> largestGap = LedgerDirUtil.findLargestGap(currentIds);
+        return largestGap.getLeft() - 1;
+    }
+
     /**
      * reads id from the "lastId" file in the given directory.
      */
@@ -660,7 +683,7 @@ public class DefaultEntryLogger implements EntryLogger {
     private void removeCurCompactionLog() {
         synchronized (compactionLogLock) {
             if (compactionLogChannel != null) {
-                if (!compactionLogChannel.getLogFile().delete()) {
+                if (compactionLogChannel.getLogFile().exists() && !compactionLogChannel.getLogFile().delete()) {
                     LOG.warn("Could not delete compaction log file {}", compactionLogChannel.getLogFile());
                 }
 
@@ -816,7 +839,7 @@ public class DefaultEntryLogger implements EntryLogger {
 
     @Override
     public ByteBuf readEntry(long location) throws IOException, Bookie.NoEntryException {
-        return internalReadEntry(location, -1L, -1L, false /* validateEntry */);
+        return internalReadEntry(-1L, -1L, location, false /* validateEntry */);
     }
 
 
@@ -1036,6 +1059,9 @@ public class DefaultEntryLogger implements EntryLogger {
         // entry log
         try {
             return extractEntryLogMetadataFromIndex(entryLogId);
+        } catch (FileNotFoundException fne) {
+            LOG.warn("Cannot find entry log file {}.log : {}", Long.toHexString(entryLogId), fne.getMessage());
+            throw fne;
         } catch (Exception e) {
             LOG.info("Failed to get ledgers map index from: {}.log : {}", entryLogId, e.getMessage());
 
