@@ -1,4 +1,4 @@
-/**
+/*
  *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -63,6 +63,16 @@ public class InMemoryEntryLogMetadataMap implements EntryLogMetadataMap {
         return entryLogMetaMap.size();
     }
 
+    @Override
+    public boolean isEmpty() {
+        return entryLogMetaMap.isEmpty();
+    }
+
+    @Override
+    public void clear() {
+        entryLogMetaMap.clear();
+    }
+
     @Override
     public void close() throws IOException {
         entryLogMetaMap.clear();
