@@ -1,4 +1,4 @@
-/**
+/*
  *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -27,7 +27,6 @@ import java.io.IOException;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.concurrent.ConcurrentMap;
-
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.ScheduledFuture;
@@ -52,7 +51,7 @@ class LedgerDirsMonitor {
     private final ServerConfiguration conf;
     private final DiskChecker diskChecker;
     private final List<LedgerDirsManager> dirsManagers;
-    private long minUsableSizeForHighPriorityWrites;
+    private final long minUsableSizeForHighPriorityWrites;
     private ScheduledExecutorService executor;
     private ScheduledFuture<?> checkTask;
 
@@ -69,6 +68,10 @@ class LedgerDirsMonitor {
 
     private void check(final LedgerDirsManager ldm) {
         final ConcurrentMap<File, Float> diskUsages = ldm.getDiskUsages();
+        boolean someDiskFulled = false;
+        boolean highPriorityWritesAllowed = true;
+        boolean someDiskRecovered = false;
+
         try {
             List<File> writableDirs = ldm.getWritableLedgerDirs();
             // Check all writable dirs disk space usage.
@@ -100,6 +103,7 @@ class LedgerDirsMonitor {
                     });
                     // Notify disk full to all listeners
                     ldm.addToFilledDirs(dir);
+                    someDiskFulled = true;
                 }
             }
             // Let's get NoWritableLedgerDirException without waiting for the next iteration
@@ -109,7 +113,6 @@ class LedgerDirsMonitor {
             ldm.getWritableLedgerDirs();
         } catch (NoWritableLedgerDirException e) {
             LOG.warn("LedgerDirsMonitor check process: All ledger directories are non writable");
-            boolean highPriorityWritesAllowed = true;
             try {
                 // disk check can be frequent, so disable 'loggingNoWritable' to avoid log flooding.
                 ldm.getDirsAboveUsableThresholdSize(minUsableSizeForHighPriorityWrites, false);
@@ -133,11 +136,11 @@ class LedgerDirsMonitor {
                 float totalDiskUsage = diskChecker.getTotalDiskUsage(ldm.getAllLedgerDirs());
                 if (totalDiskUsage < conf.getDiskLowWaterMarkUsageThreshold()) {
                     makeWritable = true;
-                } else {
+                } else if (LOG.isDebugEnabled()) {
                     LOG.debug(
-                        "Current TotalDiskUsage: {} is greater than LWMThreshold: {}."
-                                + " So not adding any filledDir to WritableDirsList",
-                        totalDiskUsage, conf.getDiskLowWaterMarkUsageThreshold());
+                            "Current TotalDiskUsage: {} is greater than LWMThreshold: {}."
+                                    + " So not adding any filledDir to WritableDirsList",
+                            totalDiskUsage, conf.getDiskLowWaterMarkUsageThreshold());
                 }
             }
             // Update all full-filled disk space usage
@@ -147,6 +150,7 @@ class LedgerDirsMonitor {
                     if (makeWritable) {
                         ldm.addToWritableDirs(dir, true);
                     }
+                    someDiskRecovered = true;
                 } catch (DiskErrorException e) {
                     // Notify disk failure to all the listeners
                     for (LedgerDirsListener listener : ldm.getListeners()) {
@@ -158,6 +162,7 @@ class LedgerDirsMonitor {
                     if (makeWritable) {
                         ldm.addToWritableDirs(dir, false);
                     }
+                    someDiskRecovered = true;
                 } catch (DiskOutOfSpaceException e) {
                     // the full-filled dir is still full-filled
                     diskUsages.put(dir, e.getUsage());
@@ -169,6 +174,22 @@ class LedgerDirsMonitor {
                 listener.fatalError();
             }
         }
+
+        if (conf.isReadOnlyModeOnAnyDiskFullEnabled()) {
+            if (someDiskFulled && !ldm.getFullFilledLedgerDirs().isEmpty()) {
+                // notify any disk full.
+                for (LedgerDirsListener listener : ldm.getListeners()) {
+                    listener.anyDiskFull(highPriorityWritesAllowed);
+                }
+            }
+
+            if (someDiskRecovered && ldm.getFullFilledLedgerDirs().isEmpty()) {
+                // notify all disk recovered.
+                for (LedgerDirsListener listener : ldm.getListeners()) {
+                    listener.allDisksWritable();
+                }
+            }
+        }
     }
 
     private void check() {
@@ -202,7 +223,7 @@ class LedgerDirsMonitor {
     public void shutdown() {
         LOG.info("Shutting down LedgerDirsMonitor");
         if (null != checkTask) {
-            if (checkTask.cancel(true)) {
+            if (checkTask.cancel(true) && LOG.isDebugEnabled()) {
                 LOG.debug("Failed to cancel check task in LedgerDirsMonitor");
             }
         }
