@@ -43,7 +43,6 @@ import lombok.extern.slf4j.Slf4j;
 import org.apache.bookkeeper.client.BKException;
 import org.apache.bookkeeper.client.BKException.ZKException;
 import org.apache.bookkeeper.common.concurrent.FutureUtils;
-import org.apache.bookkeeper.common.util.SafeRunnable;
 import org.apache.bookkeeper.net.BookieId;
 import org.apache.bookkeeper.proto.DataFormats.BookieServiceInfoFormat;
 import org.apache.bookkeeper.versioning.LongVersion;
@@ -68,7 +67,7 @@ public class ZKRegistrationClient implements RegistrationClient {
     static final int ZK_CONNECT_BACKOFF_MS = 200;
 
     class WatchTask
-        implements SafeRunnable,
+        implements Runnable,
                    Watcher,
                    BiConsumer<Versioned<Set<BookieId>>, Throwable>,
                    AutoCloseable {
@@ -119,7 +118,7 @@ public class ZKRegistrationClient implements RegistrationClient {
         }
 
         @Override
-        public void safeRun() {
+        public void run() {
             if (isClosed()) {
                 return;
             }
@@ -241,7 +240,9 @@ public class ZKRegistrationClient implements RegistrationClient {
         // because it can happen than this method is called inside the main
         // zookeeper client event loop thread
         Versioned<BookieServiceInfo> resultFromCache = bookieServiceInfoCache.get(bookieId);
-        log.debug("getBookieServiceInfo {} -> {}", bookieId, resultFromCache);
+        if (log.isDebugEnabled()) {
+            log.debug("getBookieServiceInfo {} -> {}", bookieId, resultFromCache);
+        }
         if (resultFromCache != null) {
             return CompletableFuture.completedFuture(resultFromCache);
         } else {
@@ -480,7 +481,9 @@ public class ZKRegistrationClient implements RegistrationClient {
 
         @Override
         public void process(WatchedEvent we) {
-            log.debug("zk event {} for {} state {}", we.getType(), we.getPath(), we.getState());
+            if (log.isDebugEnabled()) {
+                log.debug("zk event {} for {} state {}", we.getType(), we.getPath(), we.getState());
+            }
             if (we.getState() == KeeperState.Expired) {
                 log.info("zk session expired, invalidating cache");
                 bookieServiceInfoCache.clear();
@@ -500,7 +503,9 @@ public class ZKRegistrationClient implements RegistrationClient {
                     readBookieServiceInfoAsync(bookieId);
                     break;
                 default:
-                    log.debug("ignore cache event {} for {}", we.getType(), bookieId);
+                    if (log.isDebugEnabled()) {
+                        log.debug("ignore cache event {} for {}", we.getType(), bookieId);
+                    }
                     break;
             }
         }
