@@ -20,6 +20,8 @@
  */
 package org.apache.bookkeeper.bookie;
 
+import static org.apache.bookkeeper.bookie.storage.EntryLogTestUtils.assertEntryEquals;
+import static org.apache.bookkeeper.bookie.storage.EntryLogTestUtils.makeEntry;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
@@ -37,6 +39,7 @@ import com.google.common.collect.Sets;
 import io.netty.buffer.ByteBuf;
 import io.netty.buffer.Unpooled;
 import io.netty.buffer.UnpooledByteBufAllocator;
+import io.netty.util.ReferenceCountUtil;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.IOException;
@@ -894,6 +897,29 @@ public class DefaultEntryLogTest {
         Assert.assertEquals("EntryId", 1L, readEntryId);
     }
 
+    @Test
+    public void testReadEntryWithoutLedgerID() throws Exception {
+        List<Long> locations = new ArrayList<>();
+        // `+ 1` is not a typo: create one more log file than the max number of o cached readers
+        for (int i = 0; i < 10; i++) {
+            ByteBuf e = makeEntry(1L, i, 100);
+            long loc = entryLogger.addEntry(1L, e.slice());
+            locations.add(loc);
+        }
+        entryLogger.flush();
+        for (Long loc : locations) {
+            int i = locations.indexOf(loc);
+            ByteBuf data = entryLogger.readEntry(loc);
+            assertEntryEquals(data, makeEntry(1L, i, 100));
+            long readLedgerId = data.readLong();
+            long readEntryId = data.readLong();
+            Assert.assertEquals("LedgerId", 1L, readLedgerId);
+            Assert.assertEquals("EntryId", i, readEntryId);
+            ReferenceCountUtil.release(data);
+        }
+    }
+
+
     /*
      * tests basic logic of EntryLogManager interface for
      * EntryLogManagerForEntryLogPerLedger.
