@@ -41,7 +41,6 @@ import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
 import com.google.common.collect.Lists;
-
 import java.time.Duration;
 import java.util.HashSet;
 import java.util.List;
@@ -49,9 +48,7 @@ import java.util.Set;
 import java.util.concurrent.CompletableFuture;
 import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.ScheduledExecutorService;
-
 import lombok.extern.slf4j.Slf4j;
-
 import org.apache.bookkeeper.client.BKException.ZKException;
 import org.apache.bookkeeper.common.testing.executors.MockExecutorController;
 import org.apache.bookkeeper.discover.RegistrationClient.RegistrationListener;
@@ -74,6 +71,7 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.TestName;
 import org.junit.runner.RunWith;
+import org.powermock.core.classloader.annotations.PowerMockIgnore;
 import org.powermock.core.classloader.annotations.PrepareForTest;
 import org.powermock.modules.junit4.PowerMockRunner;
 
@@ -81,6 +79,7 @@ import org.powermock.modules.junit4.PowerMockRunner;
  * Unit test of {@link RegistrationClient}.
  */
 @RunWith(PowerMockRunner.class)
+@PowerMockIgnore({"javax.xml.*", "org.xml.*", "org.w3c.*", "com.sun.org.apache.xerces.*"})
 @PrepareForTest({ ZKRegistrationClient.class, ZkUtils.class })
 @Slf4j
 public abstract class AbstractTestZkRegistrationClient extends MockZooKeeperTestCase {
@@ -151,7 +150,7 @@ public abstract class AbstractTestZkRegistrationClient extends MockZooKeeperTest
                         Code.NONODE.intValue(),
                         new byte[] {},
                         new Stat());
-            mockZkGetData(regReadonlyPath + "/" + address.toString(),
+            mockZkGetData(regReadonlyPath + "/" + address,
                         zkRegistrationClient.isBookieAddressTracking(),
                         Code.OK.intValue(),
                         new byte[] {},
@@ -162,7 +161,7 @@ public abstract class AbstractTestZkRegistrationClient extends MockZooKeeperTest
                         Code.OK.intValue(),
                         new byte[] {},
                         new Stat());
-            mockZkGetData(regReadonlyPath + "/" + address.toString(),
+            mockZkGetData(regReadonlyPath + "/" + address,
                         zkRegistrationClient.isBookieAddressTracking(),
                         Code.NONODE.intValue(),
                         new byte[] {},
